Contributors
============

Thanks to all the contributors!

- José Dinuncio [jdinuncio]

- Jian Aijun [jianaijun]

- Jan Müller [jan-mue]

- Percy Barboza

- Gagaro [Gagaro]

- Mauro Amico [mamico] 

- Thomas Clement Mogensen [tmog]

- Alessandro Pisa [ale-rt]
